######
Mosaiq
######

*******
Summary
*******

.. automodule:: pymedphys.mosaiq
    :no-members:



***
API
***

Connect and Query the Mosaiq Database
-------------------------------------

.. autofunction:: pymedphys.mosaiq.connect

.. autofunction:: pymedphys.mosaiq.execute
